@@ -5,31 +5,18 @@ class Event(object):
         self.code = code  # numeric code for interaction channel
         self.time = time  # in ms
         self.vertex = vertex or (None, None, None)  # x, y, z coordinates
-        self.incoming_particles = incoming or []  # list of particles, each is a tuple containing PID, energy, direction (xyz)
+        self.incoming_particles = incoming or []  # list of tuples containing PID, energy, direction (x, y, z)
         self.outgoing_particles = outgoing or []
 
     def __repr__(self):
         return "Event(code=%i, time=%s, vertex=%s, incoming=%s, outgoing=%s)" \
-               % (self.code, self.time, self.vertex, self.incoming_particles, self.outgoing_particles)
+                % (self.code, self.time, self.vertex, self.incoming_particles, self.outgoing_particles)
 
     def __setattr__(self, name, value):
         if name in ("incoming_particles", "outgoing_particles") and hasattr(self, name):
             raise AttributeError("%s is a list. Append to it instead of overwriting it." % name)
         object.__setattr__(self, name, value)
 
-    def rotate(self, dx):
-        """Rotate event around the x axis by dx degrees."""
-        # Original code snippet from Lukas Koch:
-        #
-        # sA = np.sin(10.0 * A * np.pi / 180.0)
-        # cA = np.cos(10.0 * A * np.pi / 180.0)
-        # new_dy = cA * dy - sA * dz
-        # new_dz = cA * dz + sA * dy
-
-        # -> iterate over `incoming_particles` and `outgoing_particles` and rotate each of them
-        # then, add `--rotate` command line option in `genevts.py` and wire it up to this function
-        pass
-
     def nuance_string(self, i):
         """Return NUANCE-formatted representation of event for writing to output file.
 
@@ -48,3 +35,39 @@ class Event(object):
             s += "$ track %i %.5f %.5f %.5f %.5f 0\n" % (pid, e, dirx, diry, dirz)
         s += "$ end\n"
         return s
+
+    def ratpac_string(self, i, events):
+        """Return RAT-PAC readable HEPEVT-style representation of event for writing to output file.
+
+        Input:
+            i: number of event
+            events: list of all events
+        Output:
+            String describing event."""
+
+        GeV = 0.001   # convert from MeV
+        mm = 10       # convert from cm
+        ns = 1000000  # convert from ms
+        
+        dt = self.time
+        if i > 0:
+            dt -= events[i-1].time
+        
+        s = "%i\n"  % len(self.outgoing_particles)
+        for idx, (pid, e, dirx, diry, dirz) in enumerate(self.outgoing_particles):
+            mass = 0.0
+            if pid == 11 or pid == -11:
+                mass = 0.5109907
+            if pid == 22:
+                mass = 0.0
+            if pid == 2112:
+                mass = 939.56563
+            p2 = (e**2) - (mass**2)
+            p = p2**0.5
+            px = dirx*p
+            py = diry*p
+            pz = dirz*p
+            if idx > 0:
+                dt = 0.0
+            s += "1 %i 0 0 %.8e %.8e %.8e %.8e %.5e %.5e %.5e %.5e\n" % (pid, px*GeV, py*GeV, pz*GeV, mass*GeV, dt*ns, self.vertex[0]*mm, self.vertex[1]*mm, self.vertex[2]*mm)
+        return s
